/**
 * @file Logger utility
 * @description Logger utility for the application
 */
import pino from 'pino';
/**
 * Redacts sensitive data from objects before logging
 * @param obj - Object to redact
 * @param sensitiveKeys - Array of sensitive keys to redact
 * @returns Redacted object
 */
function redactSensitiveData(obj, sensitiveKeys = ['privateKey', 'secretKey', 'password']) {
    if (typeof obj !== 'object' || obj === null) {
        return obj;
    }
    const redacted = { ...obj };
    for (const key in redacted) {
        if (sensitiveKeys.includes(key)) {
            redacted[key] = '[REDACTED]';
        }
        else if (typeof redacted[key] === 'object') {
            redacted[key] = redactSensitiveData(redacted[key], sensitiveKeys);
        }
    }
    return redacted;
}
/**
 * Creates a logger instance with the given name
 * @param name - Name for the logger instance
 * @returns Pino logger instance
 */
export function createLogger(name) {
    return pino({
        name,
        level: process.env.LOG_LEVEL || 'info',
        transport: process.env.NODE_ENV === 'development' ? {
            target: 'pino-pretty',
            options: {
                colorize: true,
                translateTime: 'HH:MM:ss',
                ignore: 'pid,hostname'
            }
        } : undefined,
        serializers: {
            err: pino.stdSerializers?.err || ((err) => ({
                type: err.name,
                message: err.message,
                stack: err.stack
            })),
            // Custom serializer for sensitive data
            data: (obj) => redactSensitiveData(obj)
        },
        formatters: {
            level(label) {
                return { level: label };
            }
        },
        timestamp: () => `,"time":"${new Date(Date.now()).toISOString()}"`,
        // Additional context that will be added to all log records
        base: {
            env: process.env.NODE_ENV || 'development',
            version: process.env.npm_package_version
        }
    });
}
/**
 * Default logger instance for the library
 */
export const logger = createLogger('nostr-dm-magiclink-utils');
//# sourceMappingURL=logger.js.map